==> dde-session-shell_5.5.66.orig.tar.xz: dde-session-shell-5.5.66/translations/dde-session-shell_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Identificació facial</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifica la identificació facial</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Identificació facial blocada. Useu la contrasenya.</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifiqueu l&apos;empremta</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Empremta blocada. Si us plau, useu la contrasenya.</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID d&apos;iris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifica la identificació d&apos;iris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Identificació d&apos;iris blocada. Useu la contrasenya.</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restableix la contrasenya</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Heu oblidat la contrasenya?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restableix la contrasenya</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Heu oblidat la contrasenya?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorrecte</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Cal la clau</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Marqueu el PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Compte</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>La contrasenya caducarà d&apos;aquí a %d dia; canvieu-la oportunament.</numerusform><numerusform>La contrasenya caducarà d&apos;aquí a %d dies; canvieu-la oportunament.</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>La contrasenya ha caducat. Si us plau, canvieu-la.</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Compte incorrecte</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Pantalla de bloqueig</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ha fallat blocar la pantalla.</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>S&apos;ha acabat el temps d&apos;espera de la verificació de l&apos;empremta. Si us plau, escriviu la contrasenya manualment.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Ha fallat la coincidència de contrasenyes.</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa de l&apos;aturada. Segur que voleu que m&apos;aturi?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa del reinici. Segur que voleu que em reiniciï?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Heu activat el nivell de seguretat del sistema alt i, per tant, no podeu canviar al mode Wayland. Desactiveu el nivell de seguretat alt al Centre de seguretat i torneu-ho a provar.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Surt de la sessió</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Canvia d&apos;usuari</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Canvia de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Inicia el monitor del sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador s&apos;aturi i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Per tancar el programa, cliqueu a Cancel·la i, a continuació, tanqueu el programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador es reiniciï i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador es posi en suspensió i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador hiberni i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador surti de la sessió i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Segur que voleu que m&apos;aturi?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Segur que voleu que em reiniciï?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Segur que voleu sortir de la sessió?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Activa</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desactiva</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.86.orig.tar.xz: dde-session-shell-5.5.86/translations/dde-session-shell_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Identificació facial</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifica la identificació facial</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Identificació facial blocada. Useu la contrasenya.</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Dispositiu no disponible!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifiqueu l&apos;empremta</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Empremta blocada. Si us plau, useu la contrasenya.</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID d&apos;iris</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifica la identificació d&apos;iris</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Identificació d&apos;iris blocada. Useu la contrasenya.</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contrasenya</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restableix la contrasenya</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Heu oblidat la contrasenya?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Si us plau, torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Restableix la contrasenya</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Heu oblidat la contrasenya?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificació correcta</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ha fallat la verificació. Resta %n intent.</numerusform><numerusform>Ha fallat la verificació. Resten %n intents.</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ha fallat la verificació. Només resta un intent.</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorrecte</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Cal la clau</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Marqueu el PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Torneu-ho a intentar d&apos;aquí a %n minut.</numerusform><numerusform>Torneu-ho a intentar d&apos;aquí a %n minuts.</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Si us plau, torneu-ho a intentar d&apos;aquí a 1 minut.</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Compte</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>La contrasenya ha caducat. Si us plau, canvieu-la.</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Compte incorrecte</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Contrasenya incorrecta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Pantalla de bloqueig</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ha fallat blocar la pantalla.</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>S&apos;ha acabat el temps d&apos;espera de la verificació de l&apos;empremta. Si us plau, escriviu la contrasenya manualment.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Ha fallat la coincidència de contrasenyes.</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa de l&apos;aturada. Segur que voleu que m&apos;aturi?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Els usuaris anteriors encara tenen la sessió oberta i se&apos;n perdran les dades a causa del reinici. Segur que voleu que em reiniciï?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Heu activat el nivell de seguretat del sistema alt i, per tant, no podeu canviar al mode Wayland. Desactiveu el nivell de seguretat alt al Centre de seguretat i torneu-ho a provar.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloqueja</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Surt de la sessió</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Canvia d&apos;usuari</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Canvia de sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Inicia el monitor del sistema</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador s&apos;aturi i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Per tancar el programa, cliqueu a Cancel·la i, a continuació, tanqueu el programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador es reiniciï i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador es posi en suspensió i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador hiberni i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Els programes eviten que l’ordinador surti de la sessió i forçar-ho pot causar pèrdues de dades.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Atura&apos;t</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reinicia</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspèn</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hiberna</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Tanca la sessió</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Segur que voleu que m&apos;aturi?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Segur que voleu que em reiniciï?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Segur que voleu sortir de la sessió?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Activa</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Desactiva</translation>
    </message>
</context>
</TS>
